<!--
    For cXML license agreement information, please see
    http://www.cxml.org/home/license.asp
    
    $Id: //ariba/cxml/schema/Modules/Approval.mod#0 $
-->

<!-- ====
    This module is built as part of cXML DTD file.
==== -->


<!--
	Request that buyers use to send an approval notification for an order confirmation that contains line item values 
	that exceed the buyer's tolerances. The buyer can Approve, Reject, or Approve and Update the purchase order. The header 
	includes a reference to the original ConfirmationRequest document, which in turn references the original purchase order.

    ApprovalRequestHeader: The approval request header contains data that is relevant for the entire approval request. 
	This includes data about type of approval, date, and reference documents.
    
	AcceptanceItem: Approval request can contain one or more acceptance items. Acceptance item provides details about 
	a specific approval of a line item.
	
    ApprovalItem (Deprecated. Use AcceptanceItem instead): A approval request can contain one or more approval items. 
	A approval item provides details about a specific approval of a line item.
-->
<!ELEMENT ApprovalRequest (ApprovalRequestHeader, (AcceptanceItem* | ApprovalItem*))>

<!--
	Contains data that is relevant for the entire approval request. This includes data about type of approval, date, reference documents.
	
    DocumentReference: Contains the payloadId of the underlaying document which is to approved. For example: OrderConfirmation.payloadId.
	
	cXMLAttachment: Contains the original (cXML) document which is to be approved, for example, original order confirmation cXML.
	
	Contact: Contact information for the document partners.
	
	Comments: Top-level comments.
-->
<!ELEMENT ApprovalRequestHeader (DocumentReference, cXMLAttachment , Contact?, Comments?, Extrinsic*)>
<!--
	@attr approvalStatus Approval status of the request (enumeration).
	
	@attr type The type of document needing approval. The only possible value is "orderConfirmation".

	@attr creationDate Date and time when the document was created.

	@attr approvalStartDate Reserved for future use. The date and time on which the approval is allowed to start.

	@attr approvalEndDate Reserved for future use. The date and time on which the approval is allowed to end.
-->
<!ATTLIST ApprovalRequestHeader
    approvalStatus           (approved | awaitingApproval | reject | approvedAndUpdatePO)         #IMPLIED
	type                   	 (orderConfirmation)  #REQUIRED
    creationDate              %datetime.tz;         #REQUIRED
    approvalStartDate         %datetime.tz;         #IMPLIED
	approvalEndDate           %datetime.tz;         #IMPLIED
>

<!--
	Usage of ApprovalItem is deprecated! Use AcceptanceItem instead.
	Line item that has to approved.
	
	UnitOfMeasure: Unit of measure to specify the quantity.
	
	Comments: Contains comments associated with this approval item.
-->
<!ELEMENT ApprovalItem (UnitOfMeasure, Comments?)>
<!--
	@attr lineNumber Number of the line item.

	@attr quantity Cumulative confirmed quantity of all elements of the same line item in the corresponding order confirmation.

	@attr approvalStatus Approval status of the line item (enumeration).

	@attr reason Reason why the line item is out of tolerance (enumeration).

	@attr startDate Reserved for future use.

	@hidden What shall be the content in case of let's say 100 scheduleLines with different delivery dates? 
		In such a case it's not common to have just and only ONE time period but up to the number of scheduleLines.
		Which should be shown/given? Which "startDate" and which "endDate"? Does it make sense in case there are more
		than one stratDate/endDate?

	@attr endDate Reserved for future use.

	@attr deviatedDate First delivery date of all confirmed elements of the same line item that is out of tolerance.
-->
<!ATTLIST ApprovalItem
    lineNumber                %uint;    			#REQUIRED
	quantity        		  %r8;      			#REQUIRED 
	approvalStatus           (approved | awaitingApproval | reject | approvedAndUpdatePO) 	#REQUIRED
	reason					 (quantityDeviation | dateDeviation | quantityAndDateDeviation)    #IMPLIED
	startDate				  %datetime.tz;         #IMPLIED
	endDate					  %datetime.tz;         #IMPLIED
	deviatedDate			  %datetime.tz;         #IMPLIED
>

<!--
	Line item that has to approved.
	
	DeviationReason: Deviation reason why it is not approved.
	
	Comments: Contains comments associated with this acceptance item.

	AcceptanceItemDetail: Contains the information about the deviation approved when the acceptance status is approvedAndUpdatePO.
-->
<!ELEMENT AcceptanceItem (DeviationReason*, Comments?, AcceptanceItemDetail*, Extrinsic*)>
<!--
	@attr lineNumber Number of the line item.

	@attr acceptanceStatus Acceptance status of the line item (enumeration).
-->
<!ATTLIST AcceptanceItem
	lineNumber				%uint;    			#REQUIRED
	acceptanceStatus		(approved | awaitingApproval | rejected | approvedAndUpdatePO) 	#REQUIRED
>

<!--
    Detail information for the item.
	
	AcceptanceScheduleDetail: Contains the information about the deviation approved when the acceptance status is approvedAndUpdatePO.
	
	UnitPrice: Unit price of the item. If this element is included, the unit price is updated.
	
	Extrinsic: Contains any additional information related to this AcceptanceItem.
-->
<!ELEMENT AcceptanceItemDetail (AcceptanceScheduleDetail+, UnitPrice?, Extrinsic*)>
<!--
    @attr approvedAction The action generated from the approval process. Possible values:
		<ul>
		<li>update - Updates an existing item with the lineNumber specified in the AcceptanceItem.</li>
		<li>replace - Replaces all the schedule information for an existing item with the lineNumber specified in the AcceptanceItem.</li>
		</ul>
-->
<!ATTLIST AcceptanceItemDetail
     approvedAction   (update | replace)           #IMPLIED
>

<!--
    Detail information for the schedule line.
-->
<!ELEMENT AcceptanceScheduleDetail (Extrinsic*)>
<!--
    @attr quantity Quantity approved.
    
	@attr deliveryDate Delivery date approved.
    
	@attr approvedAction The action generated from the approval process. Possible values:
		<ul>
		<li>new - Generates a new schedule line.</li>
		<li>update - Updates the schedule line of the specified lineNumber in the AcceptanceScheduleDetail.</li>
		<li>delete - The schedule line referenced no longer exists and must be deleted.</li>
		</ul>
		
	@attr lineNumber The line number of the schedule line to delete or update.	
-->
<!ATTLIST AcceptanceScheduleDetail
    quantity                 %r8;                       #REQUIRED
    deliveryDate             %datetime.tz;              #IMPLIED
    approvedAction           (new | update | delete)    #IMPLIED
    lineNumber               %uint;                     #IMPLIED
>

<!--
	Deviation reason.	
-->
<!ELEMENT DeviationReason (Comments?)>
<!--
	@attr value Type of deviation (enumeration).
-->
<!ATTLIST DeviationReason
	value					(dateDeviation | quantityDeviation | priceDeviation)         #REQUIRED
>

