<!--
    For cXML license agreement information, please see
    http://www.cxml.org/home/license.asp

    $Id: //ariba/cxml/Modules/Profile.mod#6 $
-->

<!--
    An AuthRequest is used when one party (the "receiver") receives
    credentials from another party (the "principal") and the receiver
    needs a trusted third party to validate the credentials.  The
    receiver should enclose the credentials in an AuthRequest and send
    them to the trusted third party for validation.

    If the principal attempts to authenticate by revealing the shared
    secret between itself and the trusted third party (not
    recommended), the receiver should forward the credentials as they
    were received, including the shared secret.

    If the principal attempts to authenticate through a client
    certificate (recommended), the receiver should forward the
    credentials as well as an X509Data element containing an
    X509IssuerSerial element describing the certificate used by the
    principal (the receiver normally obtains this information from its
    web server or SSL/TLS implementation).

    If the supplied credential is invalid, the trusted third party
    should respond with an empty cXML response of status 403
    (Forbidden).  If the supplied credential is valid, the trusted
    third party should respond with an AuthResponse that contains the
    valid credentials.
-->
<!ELEMENT AuthRequest (Credential+, X509Data?)>

<!--
    An X509Data element is constructed to describe an X.509 client
    certificate being used for authentication. This element (and its
    children) are derived from the XML Digital Signature standard 
	(http://www.w3.org/2000/09/xmldsig).
-->
<!ELEMENT X509Data ((X509IssuerSerial |
                     X509SKI |
                     X509SubjectName |
                     X509Certificate)+ |
                     X509CRL)>

<!--
    Contains the serial number and issuer name
    of the X.509 certificate.
-->
<!ELEMENT X509IssuerSerial (X509IssuerName, X509SerialNumber) >

<!--
    Contains the distinguished name of the issuer of the
    X.509 certificate. The distinguished name should be a string 
    representation of an LDAP Distinguished Name, as described in RFC 
    2253. For example,

    C=US, O="John Doe Data Security, Inc.", OU=Secure Server
    Certification Authority
-->
<!ELEMENT X509IssuerName (#PCDATA)> <!-- string -->

<!--
    Contains the distinguished name of the subject of the
    X.509 certificate. This should be a string representation of an 
    LDAP distinguished name, as described in RFC 2253.
-->
<!ELEMENT X509SubjectName (#PCDATA)> <!-- string -->

<!--
    Contains the serial number of the X.509 certificate.
-->
<!ELEMENT X509SerialNumber (#PCDATA)> <!-- string -->

<!--
    Contains the Subject Key Identifier of the X.509
    certificate.
 -->
<!ELEMENT X509SKI (#PCDATA)> <!-- string -->

<!--
    Contains a Base 64-encoded X.509v3 certificate.
-->
<!ELEMENT X509Certificate (#PCDATA)> <!-- string -->

<!--
    Contains a Base 64-encoded X.509v3 Certificate Revocation List.
-->
<!ELEMENT X509CRL (#PCDATA)> <!-- string -->

<!--
    This response returns a list of valid credentials of the person
    entity in the AuthRequest. An AuthResponse is returned only for a
    successful authentication. For failed authentications, an empty
    response with status 403 (Forbidden) is returned.
-->
<!ELEMENT AuthResponse (Credential)+>
<!--
	@attr expirationDate Specifies the time beyond which the information 
		contained in the AuthResponse must be discarded. In other words, 
		the inclusion of the expirationDate attribute specifies that the
        receiver of the AuthResponse may cache the information therein
        until the expirationDate.

        If expirationDate is not specified, it is assumed that caching of 
		AuthResponse information is not allowed.
-->
<!ATTLIST AuthResponse
    expirationDate %datetime.tz; #IMPLIED
>
