<!--
    For cXML license agreement information, please see
    http://www.cxml.org/home/license.asp

    $Id: //ariba/cxml/modules/Contract.mod#6 $
-->

<!--
    Definition of a contract. This is the data that is sent from the Buyer to an external buyer system.
-->
<!ELEMENT ContractRequest (ContractRequestHeader, ContractItemIn+)>

<!--
    Header of a Contract. This is the header level information in the Contract.

    LegalEntity: Legal entity defined in the external system. Smallest organizational unit of external accounting for which a complete,
        self-contained set of accounts can be created. This includes the entry of all transactions that must be posted and
        the creation of all items for legal individual financial statements, such as the balance sheet and the profit and loss statement.
        For example, Company Code for SAP.

    OrganizationalUnit: Purchase Unit or Purchase group defined in the external system.
        Purchase Unit is an organizational unit within Logistics. Almost all business transactions related to
        procurement are carried out in a purchase unit.
        A purchasing group corresponds to a buyer or group of buyers who perform the following
        purchasing activities:
		<ul>
		<li>Procuring certain articles or merchandise categories</li>
		<li>Acting as the contact for vendors</li>
		</ul>
        For example, Purchasing Organization or Purchasing Group.
			%
            <OrganizationalUnit domain="PurchasingOrganization">
                 1001
            </OrganizationalUnit>
            <OrganizationalUnit domain="PurchasingGroup">
                 10101
            </OrganizationalUnit>
			%
    DocumentInfo: Contract Id managed in the external system. This would be sent for "update" operation.
        For example,
		%
        <DocumentInfo documentID="55000000" documentType="Contract"/>
		%

    ParentContractInfo: Parent contract Id if the current contract is a part of an hierarchy.

    FollowUpDocument: This would give a hint to the ERP system that the next step should be to create "value" Contract or "quantity" contract etc.
        Example 1: 
		%
		<FollowUpDocument type="value" category="Contract"/>
		%
        Example 2: 
		%
		<FollowUpDocument type="LP" category="Scheduling Agreement"/>
		%

    QuoteRequestReference: If the contract is referencing to QuoteRequest originated from the external system, send requestId and requestDate.

    TermsOfDelivery: Optional shipping terms (incoTerms) as defined by the International Chamber of
        Commerce. These terms inform the buyer which portion of the shipping charges are their responsibility.
        For example,
		%
        <TermsOfDelivery>
            <TermsOfDeliveryCode value="TransportCondition"/>
            <ShippingPaymentMethod value ="Other"/>
            <TransportTerms value="FOB">Free on board vessel</TransportTerms>
        </TermsOfDelivery>
		%

    SupplierProductionFacilityRelations: Defines the relationships that exist between suppliers' production 
        facilities and their production facility roles.

    Note: Use "Contact" element to supply any additional Address or Location information.
-->
<!ELEMENT  ContractRequestHeader (LegalEntity, OrganizationID, OrganizationalUnit*, PaymentTerm*,
        QuoteRequestReference?, MaxAmount?, MinAmount?, MaxReleaseAmount?, MinReleaseAmount?,
        Contact*, Comments?, DocumentInfo?, ParentContractInfo?, FollowUpDocument?, TermsOfDelivery?, SupplierProductionFacilityRelations?, Extrinsic*)>
<!--
    @attr contractID The source buyer system contractID for this request.
        For example, Contract ID in the sourcing system.

    @attr type Identifies if this is a Value based contract or quantity based Contract.

    @attr createDate The date and time the contract was created/published.

    @attr agreementDate The date and time the contract was created.
        This is different from the effective and expiry date of the Contract.

    @attr effectiveDate Date the contract is available for ordering/releases.

    @attr expirationDate Date the contract is no longer available.
	
	@attr xml:lang The language or locale in which the ContractRequest content is written.

    @attr operation The operational mode of the ContractRequest. Possible values:
		<ul>
		<li>new - operation identifies a new Contract transaction.</li>
		<li>update - operation identified an update to an existing transaction.
			the DocumentInfo attribute can be used to indicate the Document information
			in the external system.</li>
        <li>delete - operation will be used to cancel an existing Contract, the
			assumption here is that the delete request will be an exact replica of the
			original request.</li>
		</ul>
-->
<!ATTLIST ContractRequestHeader
        contractID     %string;            #REQUIRED
        type       (value | quantity)      "value"
        createDate     %datetime.tz;       #IMPLIED
        agreementDate  %datetime.tz;       #IMPLIED
        effectiveDate  %datetime.tz;       #REQUIRED
        expirationDate %datetime.tz;       #IMPLIED
        xml:lang       %xmlLangCode;       #REQUIRED
        operation  (new | update | delete) "new"
        >

<!--
    The representation of a contract line item to be sent to external system.

    TermsOfDelivery: Optional item level incoTerms.

    ReferenceDocumentInfo: Optional reference document info for this line item.
        For example, Requisition or RFQ in the external system.
		%
        <ReferenceDocumentInfo lineNumber = "1">
            <DocumentInfo documentID = "RFQ12345"
                          documentType = "RFQ"
                          documentDate = "2005-11-07T07:03:34-05:00">
            </DocumentInfo>
        </ReferenceDocumentInfo>
		%
        The lineNumber attribute in the <ItemIn> will be used to specify the corresponding
        lineNumber on the contract in the source buyer system.
        At an implementation, level checks should be made to validate this.

        itemClassification attribute in the <ItemIn> will be used to specify whether the current line item is material or service.

        The external system Id of PaymentTerm can be sent as an extrinsic inside of <PaymentTerm>
        For example,
		%
        <PaymentTerm payInNumberOfDays="30">
			<Extrinsic name="Id">Net30</Extrinsic>
        </PaymentTerm>
		%
        Address in ShipTo will be used specify Location (Plant or StorageLocation for SAP) of the line item.
        For example,
		% 
        <ShipTo>
			<Address
				addressID="3000"
				addressIDDomain="buyerLocationID"
				isoCountryCode="US">
				<Name xml:lang="en">Plant 3000</Name>
			</Address>
        </ShipTo>
		%

        <IdReference> in <ItemID> will be used to send the corresponding line number of the
        contract in the external system. For example, domain = "SAPLineNumber", identifier="0100"

        The quantity attribute in the ItemIn tag should be set to target quantity. If the line item is amount based,
        it could be set to one.

        The UnitsOfMeasure of Min/MaxQuantity and Min/MaxReleaseQuantity is same as the one in ItemDetail.

        The MaxReleaseAmount/Quantity and MinReleaseAmount/Quantity at an item level
        indicate the item level amounts and quantities per release (purchase order).

        <Modifications> in <UnitPrice> will be used to send Discount amount/percent, Surcharges, Tax, etc.
        For example,
		%
        <UnitPrice>
            <Money currency="USD">1000.00</Money>
            <Modifications>
                 <Modification>
                     <AdditionalDeduction type="DISCOUNT">
                         <DeductionAmount>
                             <Money currency="USD">10.00</Money>
                         </DeductionAmount>
                     </AdditionalDeduction>
                 </Modification>
            </Modifications>
        </UnitPrice>
		%
        The Alternative at an item level indicates if this is a service line, if there are any alternatives for 
		this line. Alternative line in contracts is used in case of customer doing negotiation to get pricing on 
		alternate lines with a supplier. 

        SupplierProductionFacilityRelations: Defines the relationships that exist between suppliers' production 
        facilities and their production facility roles.
-->
<!ELEMENT ContractItemIn (MaxAmount?, MinAmount?, MaxReleaseAmount?, MinReleaseAmount?,
        MaxQuantity?, MinQuantity?, MaxReleaseQuantity?, MinReleaseQuantity?,
        TermsOfDelivery?, ItemIn, ReferenceDocumentInfo*, Alternative?, SupplierProductionFacilityRelations?, Extrinsic*)>
<!--
	@attr operation Represents the state of the Contract line item that is being sent to the external system. 
		<ul>
		<li>new - Represents new contract line item sent to External system.</li>
		<li>update - Represents update to an existing contract line item.</li>
		<li>delete - Represents instruction to delete this contract line item in external system.</li>
		</ul>

	@attr itemType Specifies the type of item. Possible values:
		<ul>
		<li>composite - Identifies an item group.</li>
		<li>item - Identifies an independent line item.</li>
		<li>lean - Indicates that no child item is expected for the line.</li>
		</ul>
		
	@attr serviceLineType Represents the type of the service line. Possible values:
		<ul>
		<li>standard - Standard service (default).</li>
		<li>blanket - Blanket service for which you don't specify a quantity. It is settled as a lump sum.</li>
		<li>contingency - A service that is not absolutely necessary to perform the order.</li>
		<li>openquantity - A service for which the sold-to party requires that the bidder offer the quantity 
			for a specific partial service.</li>
		<li>information - The line type does not describe a service and is for information purposes only.</li>
		</ul>
-->
<!ATTLIST ContractItemIn
        operation  (new | update | delete) #IMPLIED
        itemType       %lineItemType;    #IMPLIED
 		serviceLineType     %serviceLineType; #IMPLIED
        >

<!--
    Identifies Parent contract Id if the current contract is a part of an hierarchy.
-->
<!ELEMENT ParentContractInfo (DocumentInfo)>

<!--
    The representation of a contract status including line items.

    Status: The status whether a contract is created/updated successfully. It contains code and text.
        code: 200 - succeeded, 406 - failed. For example,
		%
        <Status xml:lang="en-US" code="200" text="OK">Succeeded</Status>
        <Status code="406" text="Not Acceptable">Failed. Invalid Plant 1234.</Status>
		%
-->
<!ELEMENT ContractStatusUpdateRequest (Status, ContractStatus?, Extrinsic*)>

<!--
    Status update for Contract Status.

    ContractIDInfo: The ID info of a contract created/updated in the source buyer system.
        For example, Contract Id in the sourcing system.

    Comments: Comments associated with the status update.
-->
<!ELEMENT ContractStatus (ContractIDInfo, ContractItemStatus*, Comments*)>
<!--
    @attr type Type of the contract status, for example, "created".
-->
<!ATTLIST ContractStatus
        type              %string;               #REQUIRED
        >

<!--
    Defines the ID of a contract known to the source buyer system.

    IdReference: Additional reference ID for Contract. For example, SAP AgreementId.
-->
<!ELEMENT ContractIDInfo (IdReference*)>
<!--
    @attr contractID The ID of a contract known to the source buyer system.

    @attr contractDate The date and time the contract request was created or updated.

    @attr contractType The type of the contract being referenced, for example, Scheduling Agreement.
-->
<!ATTLIST ContractIDInfo
        contractID        %string;               #REQUIRED
        contractDate      %datetime.tz;          #IMPLIED
        contractType      (scheduling_agreement) #IMPLIED
        >

<!--
  The representation of a line item in a contract status update request.

  Note: "type" attribute in <ItemStatus> specifies which kind of status that item should have. For example "created"
     "lineNumber" attribute in <ItemInfo> specifies the line number of current line item in the source buyer system.
     For example, item number in a sourcing contract.

  IdReference: The reference to a line item of the contract in the external system.
      For example, domain = "SAPLineNumber", identifier="0100"

  Comments: May be used to have a more user readable description of the code
-->
<!ELEMENT ContractItemStatus (ItemStatus, IdReference?, Comments*)>



<!--
    Use of the Contract element is deprecated

    A  mechanism for sending static contract pricing information.
-->
<!ELEMENT Contract (SupplierID+, Comments?, ItemSegment+)>
<!--
    @attr effectiveDate Date the contract is available for ordering/releases.

    @attr expirationDate Date the contract is no longer available.
-->
<!ATTLIST Contract
        effectiveDate   %datetime.tz;  #REQUIRED
        expirationDate  %datetime.tz;  #REQUIRED
        >

<!--
    Use of the ItemSegment element is deprecated.

    Defines an item segment for the index. An item segment is an
    overlay for index items, allowing suppliers to override certain
    item attributes on a per-contract basis.

    Items may be segmented by some agreed-upon user-specific key that
    is used to determine who is eligible for these particular overlaid
    attributes (such as reduced or different prices). Omitting the
    segmentKey indicates that the supplier wishes to set the given
    contract price system wide (for all users).
-->
<!ELEMENT ItemSegment (ContractItem+)>
<!--
    @attr segmentKey Optional agreed-upon string used to segment custom prices.
-->
<!ATTLIST ItemSegment
        segmentKey  %string;  #IMPLIED
        >

<!--
    Use of the ContractItem element is deprecated.

    A particular (custom) item overlay for a index item. The item is
    referenced by the supplierPartID.

    ItemID: ID for the part to be overlaid.
	
    UnitPrice: Contract price for item
	
    Extrinsic: Named overlay. The Extrinsic should be named with the
		item field name it is to overlay. The Extrinsic must contain a
		<value> element which supplies the replacement value for the item
		field. For example:
	%
    <ContractItem>
      <ItemID>
           <SupplierPartID>123456</SupplierPartID>
      </ItemID>
      <Extrinsic name="URL">http://www.newaddress.com</Extrinsic>
    </ContractItem>
	%
-->
<!ELEMENT ContractItem (ItemID, UnitPrice?, Extrinsic*)>


<!--
    For more information about these elements/entities, see the 
    cXML Reference Guide and related documents.
-->

