<!--
    For cXML license agreement information, please see
    http://www.cxml.org/home/license.asp

    $Id: //ariba/cxml/release/schema/1.2.61.1+/Modules/Index.mod#1 $
-->

<!--
     IndexItemAdd is the element used to insert an item in an index.

     ItemID: Uniquely identifies the item.
	 
     ItemDetail: General information about the item.
	 
     IndexItemDetail: Index specific item detail.

     Note: For historical reasons there is a LeadTime element in
     both ItemDetail and IndexItemDetail. For interoperability, it is
     recommended to specify the same value in both LeadTime elements.
     If different values are specified in the different LeadTime
     elements for the same IndexItemAdd, the meaning of this is
     undefined.
-->
<!ELEMENT IndexItemAdd (ItemID, ItemDetail, IndexItemDetail)>
<!--
     IndexItemDelete is the element used to remove an item from the
     index.

     ItemID: Uniquely identifies the item.
-->
<!ELEMENT IndexItemDelete (ItemID) >

<!--
     IndexItemPunchout is the element used to dynamically connect an
     index item to the supplier's resource for that item.

     ItemID: Uniquely identifies the item.
	 
     PunchoutDetail: Describes the item being accessed.
-->
<!ELEMENT IndexItemPunchout (ItemID, PunchoutDetail)>

<!--
     IndexItem is the general element for the list of items in an
     index.

     IndexItemAdd: Item(s) to be added to the index.
	 
     IndexItemDelete: Item(s) to be removed from the index.
	 
     IndexItemPunchout: PunchOut Item(s) to be added to the index.
-->
<!ELEMENT IndexItem (IndexItemAdd+ | IndexItemDelete+ | IndexItemPunchout+)>

<!--
     PunchoutDetail is the description of an item which is referenced
     in the index.
-->
<!ELEMENT PunchoutDetail (Description+, URL, Classification+,
                          UnitPrice?, UnitOfMeasure?, PriceBasisQuantity?,
                          ManufacturerName?, ManufacturerPartID?,
                          LeadTime?, ExpirationDate?, EffectiveDate?,
                          SearchGroupData*, TerritoryAvailable*,
                          Extrinsic*)>

<!--
	@attr punchoutLevel Specifies how the procurement application should present the PunchOut item to users. 
		This attribute can have the value store, aisle, shelf, or product.

		Procurement applications might display these items differently, depending on how they are tagged by 
		suppliers. For example, they might display store-level items differently than product-level items.
-->
<!ATTLIST PunchoutDetail
    punchoutLevel (store | aisle | shelf | product) "store"
>

<!--
     Index is the element used to update the list of goods and/or
     services which are being handled by the system.

     SupplierID: One or more identities by which this supplier is known. 
	 
	 Note: These are to be considered synonyms for the same Supplier.
		
     SearchGroup: Description(s) of parametric search(es) for this
        index.  Use of the SearchGroup element is
        deprecated.
		
     IndexItem: The list of items with which to modify the index.
-->
<!ELEMENT Index (SupplierID+, Comments?, SearchGroup*, IndexItem+)>
<!--
     @attr loadmode The mode in which the Index is loaded, either Full
		or Incremental. A full index load completely replace a previously 
		loaded index. The recommended application default is incremental.
-->
<!ATTLIST Index
    loadmode (Full | Incremental) #IMPLIED
>

<!--
     Use of the SearchGroup element is deprecated. Parametric search
     shapes should be defined using TypeDefinition and its child
     elements.

     SearchGroup is a grouping of attributes which constitute a search
     which can be performed against an index.

     Name: Name of the search.
	 
     SearchAttribute: List of searchable index fields.
-->
<!ELEMENT SearchGroup (Name, SearchAttribute+)>

<!--
     DEPRECATED. Do not use. 
	 
	 Parametric search shapes should be defined using TypeDefinition and its
     child elements.

     An attribute that can searched parametrically.
-->
<!ELEMENT SearchAttribute EMPTY>
<!--
     @attr name Name of the attribute.
	 
     @attr type The type of the attribute.
-->
<!ATTLIST SearchAttribute
    name  %string;  #REQUIRED
    type  %string;  #IMPLIED
>

<!--
     ExpirationDate is the date and time after which the element is no longer
     valid.  Must be specified in ISO 8601 format.
-->
<!ELEMENT ExpirationDate (#PCDATA)>   <!-- datetime.tz -->
<!--
     EffectiveDate date and time at which the element becomes valid.
     Must be specified in ISO 8601 format.
-->
<!ELEMENT EffectiveDate (#PCDATA)>    <!-- datetime.tz -->
<!--
     Contains various index specific elements that help to define an 
	 index item.
	 
     LeadTime: Time in days to receive the item.
	 
     ExpirationDate: Expiration date and time for the item in this index.
	 
     EffectiveDate: Effective date and time for the item in this index.
	 
     SearchGroupData: Parametric search data.
	 
     TerritoryAvailable: Country codes.
-->
<!ELEMENT IndexItemDetail (LeadTime, ExpirationDate?, EffectiveDate?,
                           SearchGroupData*, TerritoryAvailable*)>

<!--
     Specification of a territory (using ISO country and/or region codes)
     in which the particular index item is available.
-->
<!ELEMENT TerritoryAvailable (#PCDATA)>

<!--
     SearchGroupData specifies the data which should be used to identify
     this item in a search.
-->
<!ELEMENT SearchGroupData (Name, SearchDataElement*)>

<!--
     SearchDataElement is a field and value which are used to provide the
     parametric data to a search.
-->
<!ELEMENT SearchDataElement EMPTY>
<!--
	@attr name Element to search.

	@attr value Value to search.
-->
<!ATTLIST SearchDataElement
     name  %string; #REQUIRED
     value %string; #REQUIRED
>
