<!--
    For cXML license agreement information, please see
    http://www.cxml.org/home/license.asp

    $Id: //ariba/cxml/release/schema/1.2.61.1+/Modules/Organization.mod#1 $
-->
<!--
     Defines a supplier organization.
-->
<!ELEMENT Organization (Name, Credential+, OrganizationRole*, Address, CorporateInformation?, TaxInformation?, RelationshipInformation?, Description*,  Person*, Industry*, Commodity*, Territory*, PaymentInformation*, Extrinsic*)>

<!-- 
    Requests profile information for suppliers with which the buyer has relationships.

    The OrganizationID wrapper is used to distinguish between requests
    about multiple organizations and requests including alias Credentials
    for the same organization.
-->
<!ELEMENT OrganizationDataRequest
         (OrganizationID+)>

<!--
    Returns supplier profile information.
-->
<!ELEMENT OrganizationDataResponse (Organization+)>

<!--
	Used to push organization information to another system.
-->
<!ELEMENT OrganizationChangeMessage (Organization+)>
<!--
	@attr type Type of organization change (enumeration).
-->
<!ATTLIST OrganizationChangeMessage
    type  (new | update | delete)  #REQUIRED
>

<!-- 
	Contains corporate information for a supplier.
-->	
<!ELEMENT CorporateInformation (AnnualRevenue?, StateOfIncorporation?, OwnershipType*)>
<!--
	@attr yearFounded Year the supplier organization was founded.
	
	@attr numberOfEmployees Number of employees in the supplier organization.
	
	@attr organizationType Type of supplier organization.
-->
<!ATTLIST CorporateInformation
    yearFounded        %uint; #IMPLIED
    numberOfEmployees  %uint; #IMPLIED
    organizationType  NMTOKEN #IMPLIED
>

<!--
	State in which the supplier organization was incorporated.
-->
<!ELEMENT StateOfIncorporation (State)>

<!--
	Annual revenue of the supplier organization.
-->
<!ELEMENT AnnualRevenue (MinAmount, MaxAmount?)>

<!--
	Ownership type of the supplier organization.
-->
<!ELEMENT OwnershipType (Extrinsic*)>
<!--
	@attr name Name of ownership type. For United States companies, can be either "minorityOwned", "womanOwned", 
		"veteranOwned", "disabledVeteranOwned", or "vietnamVeteranOwned". The list is not enumerated since it can be 
		different for different countries.
-->
<!ATTLIST OwnershipType
    name  NMTOKEN #REQUIRED
>

<!--
	Contains associated tax information for an organization that can be
    used for 1099 purposes.
-->	
<!ELEMENT TaxInformation (LegalName?, TaxID*)>
<!--
	@attr isExemptFromBackupWithholding Indicates whether the organization is exempt from backup withholding.
-->
<!ATTLIST TaxInformation
    isExemptFromBackupWithholding  (yes | no) #IMPLIED
>

<!--
	Legal name of the owner of the Social Security Number or Tax Identification Number.
-->
<!ELEMENT LegalName (#PCDATA)>
<!--
	@attr xml:lang Language or locale in which the LegalName is written. 
-->
<!ATTLIST LegalName
    xml:lang  %xmlLangCode;  #REQUIRED
>

<!--
	Contains the Tax Identification Number (TIN) or Social Security Number.
-->
<!ELEMENT TaxID (#PCDATA)>
<!--
	@attr domain Specifies the type of tax ID (enumeration).
-->
<!ATTLIST  TaxID
    domain  (usSSN | usTIN | stateTIN | regionalTIN | vatID)  #REQUIRED
>

<!--
	Contains anything that is specific between the
    requester and requestee.
--> 
<!ELEMENT RelationshipInformation (PaymentRelationshipInformation?)>
		
<!--
	Contains payment information between requester and requestee. 
-->
<!ELEMENT PaymentRelationshipInformation (PaymentProviderInformation+, Extrinsic*)>
                      
<!--
	Contains information about the payment provider who is 
    going to execute payment between the requester and the requestee. 
    It has the ID of the payment provider payment service as well as 
    the payment methods that the payment provider supports. 
-->
<!ELEMENT PaymentProviderInformation (Description?, PaymentMethod+, Extrinsic*)>
<!--
	@attr paymentProviderID ID of the payment provider payment service.
-->
<!ATTLIST PaymentProviderInformation
     paymentProviderID %string; #REQUIRED
>

<!--
    Associates a particular individual with the (many) roles they may
    play on behalf of an organization.

    Note: The Contact element in this context would not include a role
    attribute since this does not describe a person acting in any particular
    fashion.
-->
<!ELEMENT Person (Contact, PersonRole+, IdReference*, Extrinsic*)>

<!--
    Contains the possible values the Contact&#064;role attribute may take
    when the associated Contact appears in a cXML Request (such as
    ProviderSetupRequest).
-->
<!ELEMENT PersonRole EMPTY>
<!--
	@attr name Name of the role of a supplier user.
-->
<!ATTLIST PersonRole
    name NMTOKEN #REQUIRED
>

<!--
	Defines the industry to which a supplier organization belongs.
-->
<!ELEMENT Industry (Classification)>

<!--
	Defines the principle commodity of a supplier organization.
-->
<!ELEMENT Commodity (Classification)>

<!--
	Defines the territory of a supplier organization.
-->
<!ELEMENT Territory (Classification)>

<!--
	Contains payment information for the organization.
-->
<!ELEMENT PaymentInformation (PaymentMethodRemittanceInformation+)>

<!--
	Contains payment remittance information for the organization, including payment methods and payment method partners.
-->
<!ELEMENT PaymentMethodRemittanceInformation (Contact, PaymentMethod*, PaymentMethodPartner*)>
<!--
	@attr isDefault Set to "yes" to indicate whether this is the default payment method remittance information.
	
	@attr preferredPaymentMethod Specifies the preferred payment method.
-->
<!ATTLIST PaymentMethodRemittanceInformation
    isDefault (yes) #IMPLIED
    preferredPaymentMethod %cxml.paymentMethod; #IMPLIED
>

<!--
	Includes the financial information of an organization into the 
    PaymentMethodRemittance tag.

	Also, for IdReference tag, we add a new domain receivingCorrspondent. This new role 
    behaves as the payee for receiving correspondent bank. We need this new role because 
    in the wire transfer case, the receiving party could have up to two banks: beneficiary 
    and corresponding banks. Hence, payee role is needed to contain the information about 
    beneficiary bank account and receivingBank role is needed to contain the information 
    about the beneficiary bank. Similarly, for the receiving correspondent bank, we have the 
    roles receivingCorresondent and receivingCorrespondentBank
-->
<!ELEMENT PaymentMethodPartner (PaymentMethod, PaymentPartner+) >

 
