<!--
    For cXML license agreement information, please see
    http://www.cxml.org/home/license.asp

    $Id: //ariba/cxml/schema/Modules/Payment.mod#1 $
-->

<!--
    This file contains all the payment related elements
-->

<!--
    Defines different payment methods
-->
<!ENTITY % cxml.paymentMethod  "(ach | cash | check |
                                creditCard | debitCard |
                                draft | wire |
                                other)">

<!--
    Defines a payment method

    Description: The description of the payment method. Description is
        mandatory if the type is set to "other". The ShortName
		element in Description must indicate the name of the payment
		method.
-->
<!ELEMENT PaymentMethod (Description?)>
<!--
	@attr type The payment method type. Possible values:
		<ul>
		<li>ach</li>
		<li>cash</li>
		<li>check</li>
		<li>creditCard</li>
		<li>debitCard</li>
		<li>draft</li>
		<li>wire</li>
		<li>other</li>
		</ul>
-->
<!ATTLIST PaymentMethod
    type %cxml.paymentMethod; #REQUIRED
>

<!--
    Defines payable information related to a invoice.

    InvoiceReference: The reference to invoice being paid. Copied from the InvoiceDetailRequest message.

    InvoiceIDInfo: The reference to invoice in the Supplier system being paid.

    PayableOrderInfo: Supplementary information related to the invoice. For example,
        if you are making a payment against a consolidated invoice,
        you may also include associated order information.

    PayableMasterAgreementInfo: Supplementary information related to the invoice. For example,
        if you are making a payment against a Consolidated Invoice,
        you may also include associated master agreement information.
-->
<!ELEMENT PayableInvoiceInfo ((InvoiceReference | InvoiceIDInfo),
                              (PayableOrderInfo | PayableMasterAgreementInfo)?)>

<!--
    Defines payable information related to an order.

    OrderReference: The reference to the order being paid.

    OrderIDInfo: The buyer system order id of the order.
-->
<!ELEMENT PayableOrderInfo (OrderReference | OrderIDInfo)>

<!--
    Defines payable information related to a master agreement.

    MasterAgreementReference: The reference to master agreement in the Buyer system being paid.
        Copied from the InvoiceDetailRequest message.

    MasterAgreementIDInfo: The reference to master agreement in the Buyer system being paid.
-->
<!ELEMENT PayableMasterAgreementInfo (MasterAgreementReference | MasterAgreementIDInfo)>

<!--
    Defines information related to a payable such as an invoice,
    order, masteragreement, receipt, etc. More than one payable
    information can be included.

    PayableInvoiceInfo: The info about the invoice being paid.

    PayableOrderInfo: The info about the order being paid.

    PayableMasterAgreeementInfo: The info about the master agreement being paid.
-->
<!ELEMENT PayableInfo ( PayableInvoiceInfo | PayableOrderInfo |
                        PayableMasterAgreementInfo)>

<!--
    Defines the party involved in the payment, including Payer of this
    payment (payer), Payee of this payment (payee),
    Payer's bank (originatingBank), Payee's bank (receivingBank),
    Payer's Correspondent Bank, Payee's Correspondent Bank, Intermediary Bank, and 
	so on.

    Contact: Contact information of the payment partner. Allowed contact
        roles include payer, payee, originatingBank, receivingBank,
        originatingCorrespondentBank, receivingCorrespondent, 
        receivingCorrespondentBank, intermediaryBank, payeeContact, and 
		remitTo.

        Contact elements with role "payer" and "payee" are always
        required. If the payment method indicates a bank transfer,
        then Contact elements with role "originatingBank" and
        "receivingBank" are required.

        If the contact role is "remitTo", it would contain contact
        information of the remittance address. For this role, the
        IdReference and PCard elements may be absent.
		
		If the contact role is payee, the name under the contact is the supplier 
		organization name. If the contact role is payeeContact, the name under 
		the contact is the supplier contact name.

    IdReference: Partner reference ID, including bank account identification,
        bank identification, and optionally bank branch identification.

        IdReference is mandatory for all transactions that involve
        electronic payments. It is optional only for non-electronic
        forms of payments, such as, "check", "draft", and so on.

        The bank account identification is specified as follows:
		<ul>
            <li>bankAccountID - Domestic account number.</li>
			<li>ibanID - IBAN ID (International Bank Account Number) as
				specified in ISO 13616.</li>
		</ul>

        The bank identification is specified as follows:
		<ul>
            <li>abaRoutingNumber - ABA (American Banking Association) Routing Number).</li>
            <li>swiftID - SWIFT ID (Society for Worldwide Interbank Financial Telecommunications).</li>
            <li>chipsID - CHIPS ID (Clearing House Interbank Payment System).</li>
            <li>isoBicID - ISO BIC ID (Bank Identifier Code) as specified in ISO 9362.
				The Bank Identifier Code (BIC) is a universal method of identifying
                financial institutions. The BIC consists of 8 or 11 characters, comprising a bank
                code (4 characters), a country code (2 characters), a location code (2
                characters) and an optional branch code (3 characters).</li>
            <li>bankNationalID - If none of the above bank identification
				methods are applicable, then use this to specify national clearing codes that are
                specific to a country. This identification if used, should uniquely identify
                the bank within the country specified in the Contact.</li>
		</ul>
	    
        The bank branch identification, if necessary, is specified as follows:
            <ul>
			<li>bankBranchID - The bank branch ID.</li>
			</ul>

        The following table illustrates some valid combinations of
        Contact and IdReference domains:
		<table colsep="1" rowsep="1">
			<thead>
				<tr>
					<th>Contact.role</th>
					<th>IdReference.domain</th>
				</tr>
			</thead>
			<tbody>
				<tr>
					<td>payer</td>
					<td>bankAccountID, ibanID</td>
				</tr>
				<tr>
					<td>payee</td>
					<td>bankAccountID, ibanID</td>
				</tr>
				<tr>
					<td>receivingCorrespondent</td>
					<td>bankAccountId, swiftID</td>
				</tr>
				<tr>
					<td>originatingBank</td>
					<td>abaRoutingNumber, bankNationalID, isoBicID, swiftID, bankBranchID (optional)</td>
				</tr>
				<tr>
					<td>receivingBank</td>
					<td>abaRoutingNumber, bankNationalID, isoBicID, swiftID, bankBranchID (optional)</td>
				</tr>
				<tr>
					<td>originatingCorrespondentBank</td>
					<td>abaRoutingNumber, isoBicID, swiftID</td>
				</tr>
				<tr>
					<td>receivingCorrespondentBank</td>
					<td>abaRoutingNumber, isoBicID, swiftID</td>
				</tr>
				<tr>
					<td>intermediaryBank</td>
					<td>abaRoutingNumber, isoBicID, swiftID</td>
				</tr>
			</tbody>
		</table>

	The IDReference can only appear for the Contact with payer role. This is used
    when the payment is done through a PCard.

    PCard: PCard information including PCard number, PCard expiration date,
		PCard name.
		
	NatureOfBusiness: Specifies the sector or industry to which a company belongs. 
		It describes what the company does. The data type is a string and can be 
		any characters with max 255 characters.

    AccountCurrency: Refers to the account currency for the current PaymentPartner
-->
<!ELEMENT PaymentPartner (Contact, IdReference*, (PCard? | PaymentToken?)? , NatureOfBusiness?, IncorporationType?, AccountCurrency?)>

<!-- 
   The nature of business refers to the sector or industry to which a company belongs. 
   It describes what the company does. The data type is string and can be any characters 
   with max 255 characters.
-->
<!ELEMENT NatureOfBusiness (#PCDATA)>
<!--
   The IncorporationType refers to the company type. The data type is string and can be any
   characters with max 255 characters.
-->
<!ELEMENT IncorporationType (#PCDATA)>

<!--
   Refers to the account currency for a PaymentPartner.
-->
<!ELEMENT AccountCurrency EMPTY>

<!-- 
    @attr code Specifies a three-letter ISO 4217 currency code.
-->
<!ATTLIST AccountCurrency
    code   %isoCurrencyCode;   #REQUIRED
>

