<!--
    Transmits inventory, consignment movement, and forecast information from the buyer’s ERP system. The buyer-provided inventory 
	summary view includes the issued components to the supplier. The provided information represents a snapshot of the component 
	inventory and forecast situation at a certain point in time. The consignment movement information represents the movement of 
	material from the consignment inventory to the customer inventory.
-->
<!ELEMENT ProductActivityMessage (ProductActivityHeader, ProductActivityDetails+, Extrinsic*)>
<!--
	@attr subcontractingIndicator Set to "yes" to indicate that the data in the message is related to subcontracting. 
-->
<!ATTLIST ProductActivityMessage
    subcontractingIndicator  (yes)          #IMPLIED
>

<!--
	Header element for the ProductActivityMessage.
-->
<!ELEMENT ProductActivityHeader EMPTY>
<!--
	@attr messageID An identifier for this particular product activity message.

	@attr creationDate The date and time this product activity message was created.
        
	@attr processType Identifies the business process supported by the message. Possible values:
        <ul>
		<li>SMI - For Supplier Managed Inventory 
         (Inventory, ConsignmentInventory, PlanningTimeSeries, InventoryTimeSeries).</li>
        <li>OEM - For Original Equipment Manufacturer owned Inventory scenarios
         (Inventory, ConsignmentInventory, TimeSeries, PlanningTimeSeries, InventoryTimeSeries).</li>
        <li>VMI - For Vendor Managed Inventory
         (Inventory, ConsignmentInventory, PlanningTimeSeries, InventoryTimeSeries).</li>
        <li>3PL - For third party Logistics Inventory Scenarios
         (Inventory, ConsignmentInventory, PlanningTimeSeries, InventoryTimeSeries).</li>
        <li>ManufacturingVisibility - Allow ContractManufacturers to share Inventory Visibility
         (Inventory, ConsignmentInventory, PlanningTimeSeries, InventoryTimeSeries).</li>
        <li>Forecast - For Forecast Collaboration
         (TimeSeries, PlanningTimeSeries).</li>
        <li>Consignment - For Consignment Material Movements 
         (ConsignmentInventory, ConsignmentMovement).</li>
        <li>Sales - For Sales report Visibility
         (SalesReport).</li>
        <li>POC - For PO Collaboration Scenarios
         (Inventory, ConsignmentInventory, TimeSeries, PlanningTimeSeries)
         Capacity for Capacity Planning (PlanningTimeSeries).</li>
		<li>Capacity - Capacity planning scenarios (PlanningTimeSeries).</li>
        <li>StockInventory - For Stock Transport Order Collaboration (Inventory).</li>
		<li>Other - Other collaboration scenarios.</li>
		</ul>
-->
<!ATTLIST ProductActivityHeader
     messageID           %string;              #REQUIRED
     creationDate           %datetime.tz;         #IMPLIED
     processType (SMI|OEM|VMI|3PL|ManufacturingVisibility|Forecast|Consignment|Sales|POC|Capacity|StockInventory|Other )  #IMPLIED
>

<!--
    The representation of a single component inventory, the product forecast details or a consignment movement for that product. 

    ItemID: A unique identification of a component item in supplier backend system or buyer backend system.

    ResourceID: A unique identification of a production facility leveraged during production, such as a piece of equipment or a production line.

    Description: Textual description of the component.

    Classification: Classification is used to group items into similar categories. This also includes product hierarchy and commodity information.
	
    SerialNumberInfo: This is a existing element. The representation of the required serial number information of a line item.
		Component Inventory will only accept only type="list" or type="range".

    ForecastDetails: Contains the cumulative start and end date of the forecast item.

    LeadTime: Lead time in days.

    PlannedAcceptanceDays: Number of days the buyer schedules for the inspection of goods after receiving them.

    ManufacturerPartID: ID with which the item's manufacturer identifies the item.
    
    ManufacturerName: Name of the item's manufacturer.

    ReferenceDocumentInfo: Contains details of referenced document.

    Characteristic: Characteristic contains detailed information about an item that can be used across different industries.
		Can also be used to send material characteristics to support configurable material process.

    Batch: Batch information of goods or material. The information includes ID and characteristics.

    Contact: The location from and to the product activity is taking place. The only Contact roles (Contact&#064;role attribute value) 
		likely to be sensible in this element are "locationFrom" and "locationTo". locationFrom can be used by the supplier system 
		to the determine the buyer notified ERP vendor ID or vendor location. locationTo can be used by the supplier system to 
		determine the location of the buyer where the product demand originates. To provide a plant location description, the 
		domain attribute of the element IdReference should be set to "buyerLocationID", "supplierLocationID" or "storageLocation" 
		and the identifier to the plantID.

    Inventory: Inventory that is in the possession of the buyer, and is owned and managed by the buyer.

    ConsignmentInventory: Inventory that is in the possession of the buyer, but is owned by the supplier.

    TimeSeries: Forecast data, can be of type "demand" or "orderForecast".

    InventoryTimeSeries: Support the transfer of projected stock, safety stock and target stock levels generated by the buyer's planning system 
		to facilitate supply or demand balance.

    ConsignmentMovement: The consignment movement information for this product.

    SalesReport: It contains all the information about the sales report at item level.

	UnitOfMeasure: The unit of measure for an inventory/forecast/consignment quantity at the Item level. This will be applicable for the entire item 
		and will be defaulted over the unit of measure maintained across the time series quantities.		

    PlanningTimeSeries: Planning information from buyers ERP system represented as keyfigures to provide visibility of critical business 
		information to suppliers and other partners.
-->
<!ELEMENT ProductActivityDetails ( (ItemID| ResourceID),  Description?, Classification*, SerialNumberInfo?, ForecastDetails?, LeadTime?, PlannedAcceptanceDays?, 
    ManufacturerPartID?, ManufacturerName?, ReferenceDocumentInfo*, Characteristic*, Batch?, Contact*, UnitPrice?, Inventory?, 
    ConsignmentInventory?, TimeSeries*, PlanningTimeSeries*, InventoryTimeSeries*, ConsignmentMovement*, 
    SalesReport?, UnitOfMeasure?, Extrinsic*)>
<!--
    @attr status Indicates whether the material used in the planning process is "active", "inactive", or "deleted".
-->
<!ATTLIST ProductActivityDetails
	status (active|inactive|deleted)		#IMPLIED
>

<!--
	Defines the start and end dates for the accumulation of the forecast for a part.
-->
<!ELEMENT ForecastDetails EMPTY>
<!--
	@attr cumulativeStartDate The start date at which the cumulative values for forecast and commit will be calculated. 
		If not provided the accumulation of the forecast for a part will start on the earliest date for which there is forecast data.

	@attr cumulativeEndDate The end date till which the cumulative values for forecast and commit will be calculated. 
-->
<!ATTLIST ForecastDetails
	cumulativeStartDate %date;       #IMPLIED
	cumulativeEndDate %date;       #IMPLIED
>

<!--
	Provides inventory data in time intervals.
-->
<!ELEMENT InventoryTimeSeries (TimeSeriesDetails+)>
<!--
	@attr type Type of inventory. Possible values:
		<ul>
		<li>targetStock - Quantity required to meet the demand, based on customer service levels.</li>
		<li>projectedStock - Calculated stock quantity that reflects the demand and supply stock balance.</li>
		<li>safetyStock - Quantity of stock required to mitigate risk of stockouts.</li>
		<li>minimumStock - Required minimum quantity of stock supplier must maintain in a given time period.</li>
		<li>maximumStock - Required maximum quantity of stock supplier must maintain in a given time period.</li>
		</ul>
-->
<!ATTLIST InventoryTimeSeries
	type	(targetStock | projectedStock | safetyStock | minimumStock | maximumStock )  #REQUIRED >

<!--
	Contains information about a sales report at the item level.

	Period: Item Sales start and end date

	Comments: It allows to enter multiple comments

	SalesQuantity: Quantity that was sold

	ReturnQuantity: Quantity that was returned

	Total: Line Item Amount

	PromotionVariantID: Promotional Variant Number
-->
<!ELEMENT
  SalesReport (
        Period,        
        SalesQuantity,
        ReturnQuantity?,
        Total?,
        PromotionVariantID?,
	Comments*
)>
<!--
	@attr salesDate Date of the sale.

	@attr lineNumber Line number of the item in the sales report.
-->
<!ATTLIST SalesReport
    salesDate      	       %datetime.tz; #IMPLIED
    lineNumber    		%uint; #REQUIRED
>

<!--
	Contains the quantity that was sold.
-->
<!ELEMENT SalesQuantity (UnitOfMeasure)>
<!-- 
	@attr quantity Number of units sold.
-->
<!ATTLIST SalesQuantity
    quantity        %r8; #REQUIRED
>

<!-- 
	Represents a time series in the forecast data.
-->
<!ELEMENT TimeSeries (Forecast+)>
<!--
	@attr type Type of time series (enumeration).
-->
<!ATTLIST TimeSeries
    type                 (orderForecast | demand)  #REQUIRED >

<!-- 
	Contains planning information from the buyers ERP system to provide visibility of critical 
	business information to suppliers and other partners.
-->
<!ELEMENT PlanningTimeSeries (TimeSeriesDetails+)>
<!--
    @attr type A string value to identify the type time series. The value can be as follows:
		<ul>
		<li>grossdemand - Quantity that is considered as demand without taking inventory and receipts into consideration.</li>
		<li>netdemand - Quantity determined based on available inventory and receipts derived based on planning output.</li>
		<li>supplyPlan - Quantity derived to meet the demand based on supply Planning.</li>
        <li>longtermforecast - Forecast quantity derived based on historical trends.</li>
		<li>constrainedforecast - Unconstrained forecast when limited by supply constraints results in constrained forecast.</li>
		<li>capacitydemand - Quantity of production output that is requested from a specific resource.</li>
        <li>custom - Buyer-specific business values could be represented by the customType string.</li>
		</ul>
		
    @attr customType String to include buyer-defined custom types, for example, "NARegionalForecast".	
-->
<!ATTLIST PlanningTimeSeries
    type (supplyPlan | longtermforecast | constrainedforecast | grossdemand| netdemand | capacitydemand | custom)  #REQUIRED 
    customType %string;   #IMPLIED >

<!-- 
	Contains consignment movement information for this product, tracking movement from consignment inventory to customer inventory. 

    ProductMovementItemIDInfo: Provides a reference to the line item in a movement document

    InvoiceItemIDInfo: Line item of a CC Invoice created by the buyer against the movement item
	
	ReferenceDocumentInfo: Contains details of a referenced document in the consignment procurement process 
		such as Purchase Order, Scheduling Agreement, Ship Notice, and Receipt.
	
    MovementQuantity: The quantity moved in a consignment movement.
	
    SubtotalAmount: The invoice subtotal of the current item.
	
    UnitPrice: Represents the price on which the charges are applied. For example, standard price for item is 10, but after being 
		for 30 days in the consignment inventory the price will increase to 12.
	
	Extrinsic: Additional information related to this document.
-->
<!ELEMENT ConsignmentMovement (ProductMovementItemIDInfo, InvoiceItemIDInfo?, ReferenceDocumentInfo?, MovementQuantity, SubtotalAmount, UnitPrice?, Extrinsic*)>