<!--
    The representation of a line item as it needs to be for sending to a
    supplier.
-->
<!ELEMENT QuoteItemOut (ItemID?, ItemDetail, ShipTo?, Shipping?,
                   Tax?, SpendDetail?, Total?, TermsOfDelivery?, ReferenceDocumentInfo?, Contact*, Comments?, Alternative?, SupplierSelector?)>
<!--
    @attr quantity How many items are desired. 

    @attr lineNumber Position (counting from 1) of this item in a QuoteRequest. Used to
        maintain a reference between items in create and update documents.

	@attr parentLineNumber Position (counting from 1) of this item's parent in a QuoteRequest. 
		Used to maintain a hierarchical reference between items in documents.

    @attr requestedDeliveryDate The date this item was requested for delivery.

    @attr agreementItemNumber The corresponding Item Number of the Item in the Master Agreement if this 
		is a "release" order item.

    @attr itemClassification The service item type. It could either be "material" or "service".

	@attr itemType Specifies the type of item. Possible values:
		<ul>
		<li>composite - Identifies an item group.</li>
		<li>item - Identifies an independent line item.</li>
		<li>lean - Indicates that no child item is expected for the line.</li>
		</ul>

	@attr serviceLineType Represents the type of the service line. Possible values:
		<ul>
		<li>standard (default) - Standard service.</li>
		<li>blanket - Blanket service for which you don't specify a quantity. It is settled as a lump sum.</li>
		<li>contingency - A service that is not absolutely necessary to perform the order.</li>
		<li>openquantity - A service for which the sold-to party requires that the bidder offer the quantity 
			for a specific partial service.</li>
		<li>information - The line type does not describe a service and is for information purposes only.</li>
		</ul>
-->
<!ATTLIST QuoteItemOut
    quantity               %r8;      #REQUIRED
    lineNumber             %uint;    #IMPLIED
	parentLineNumber       %uint;         #IMPLIED
    requestedDeliveryDate  %datetime.tz;    #IMPLIED
    itemClassification     %serviceItemType; #IMPLIED
	itemType       %lineItemType;    #IMPLIED   
	serviceLineType     %serviceLineType; #IMPLIED
>

<!--
    The representation of quote items associated with the header.
-->
<!ELEMENT QuoteHeaderInfo (LegalEntity?, OrganizationalUnit*, PaymentTerms*, FollowUpDocument?, DocumentReference?, Extrinsic*)>

<!--
    The representation of a line item in a quote.

    SupplierProductionFacilityRelations: Defines the relationships that exist between suppliers' production 
        facilities and their production facility roles.
-->
<!ELEMENT QuoteItemIn (ItemID?, ItemDetail, ShipTo?, Shipping?,
                   Tax?, SpendDetail?, Total?, TermsOfDelivery?, ReferenceDocumentInfo*, Contact*, Comments?, Alternative?, SupplierProductionFacilityRelations?, Extrinsic*)>
<!--
    @attr type Supplier action type.
	
    @attr quantity How many items are quoted.
	
    @attr lineNumber Position (counting from 1) of this item in a QuoteRequest. Used to maintain a 
		reference between items in create and update documents. 
	
	@attr parentLineNumber Position (counting from 1) of this item's parent in a QuoteRequest. Used to
        maintain a hierarchical reference between items in documents.
		
    @attr requestedDeliveryDate The date this item was requested for delivery.
	
    @attr rank The rank of the bid.
	
    @attr itemClassification The service item type. It could either be "material" or "service".
	
	@attr itemType Specifies the type of item. Possible values:
		<ul>
		<li>composite - Identifies an item group.</li>
		<li>item - Identifies an independent line item.</li>
		<li>lean - Indicates that no child item is expected for the line.</li>
		</ul>
		
	@attr serviceLineType Represents the type of the service line. Possible values:
		<ul>
		<li>standard - Standard service (default).</li>
		<li>blanket - Blanket service for which you don't specify a quantity. It is settled as a lump sum.</li>
		<li>contingency - A service that is not absolutely necessary to perform the order.</li>
		<li>openquantity - A service for which the sold-to party requires that the bidder offer the quantity 
			for a specific partial service.</li>
		<li>information - The line type does not describe a service and is for information purposes only.</li>
		</ul>
-->
<!ATTLIST QuoteItemIn
    type  (accept | reject | update | final | award) #REQUIRED
    quantity               %r8;      #REQUIRED
    lineNumber             %uint;    #IMPLIED
	parentLineNumber       %uint;         #IMPLIED
    requestedDeliveryDate  %datetime.tz;    #IMPLIED
    rank                   %r8;      #IMPLIED
    itemClassification     %serviceItemType; #IMPLIED
	itemType       %lineItemType;    #IMPLIED   
	serviceLineType     %serviceLineType; #IMPLIED
>

<!--
    Header of an QuoteMessage. This is the quote data that is sent to the buyer. 

    SupplierProductionFacilityRelations: Defines the relationships that exist between suppliers' production 
        facilities and their production facility roles.
-->
<!ELEMENT QuoteMessageHeader (OrganizationID, Total, ShipTo?, Contact*, QuoteRequestReference?, Comments?, QuoteHeaderInfo?, SupplierProductionFacilityRelations?, Extrinsic*)>
<!--
    @attr type Supplier action type (enumeration).
    
	@attr quoteID Unique identifier for a quote. 
    
	@attr quoteDate The date when the quote is submitted.
	
	@attr currency Currency for the QuoteRequest and QuoteMessage. Must be a three-letter ISO currency code.
	
	@attr xml:lang The language for the QuoteRequest and QuoteMessage.
-->
<!ATTLIST QuoteMessageHeader
    type  (accept | reject | update | final | award)	#REQUIRED
    quoteID    %string;          #REQUIRED
    quoteDate  %datetime.tz;     #REQUIRED
    currency  %isoCurrencyCode;	 #REQUIRED
    xml:lang  %xmlLangCode;      #REQUIRED
>

<!--
	Reference to a quote request originated in the external system. 
-->
<!ELEMENT QuoteRequestReference (DocumentReference?)>
<!--
	@attr requestID Unique internal number from the buyer’s system for the request for quotations.
	
	@attr requestDate The date and time of the quoteRequest document.
-->
<!ATTLIST QuoteRequestReference
    requestID		%number;		#REQUIRED
    requestDate	%datetime.tz;	#REQUIRED
>

<!--
    Definition for a quote. This is the data that is sent to the buyer.
-->
<!ELEMENT QuoteMessage (QuoteMessageHeader, QuoteItemIn*)>

<!-- QuoteRequest* Elements -->
<!--
    Definition of a request for quote. This is the data that is sent to the supplier
    to have them submit a quote.
-->
<!ELEMENT QuoteRequest (QuoteRequestHeader, QuoteItemOut*)>

<!--
    Header of a QuoteRequest. This is the data that is sent to the supplier
    to have them submit a quote. 
	
	Total: The total amount of this QuoteRequest.
-->
<!ELEMENT QuoteRequestHeader (Name?, SupplierSelector?, Total?, Description?, ShipTo?, Contact*, Comments?, QuoteHeaderInfo?, Extrinsic*)>
<!--
    @attr requestID The buyer system ID for this request. This is an internal
        Buyer unique number.

    @attr requestDate The date and time the QuoteRequest request was created.

    @attr type The type of the QuoteRequest request. Defaults to "new".

    @attr openDate The date when a QuoteRequest is open for supplier responses.
	
    @attr closeDate The date when a QuoteRequest is closed for supplier responses.
	
    @attr previewDate The date when a QuoteRequest is viewable by suppliers.
	
	@attr templateName The template used by the sourcing application. The template can outline the terms 
		and conditions regarding the details for a request for quotation sent between the buyer and 
		sourcing application.
		
	@attr currency Currency for the QuoteRequest and QuoteMessage. Must be a three-letter ISO currency code.
	
	@attr xml:lang The language for the QuoteRequest and QuoteMessage.

    @attr quoteReceivingPreference Used by the buyer system to identify the preference for
        receiving QuoteMessage back from the sourcing system. Possible values are:
		<ul>
		<li>winningOnly - should result in only the winning supplier quotes being sent to the buyer.</li>
		<li>finalBidsFromAll - should result in  quotes from suppliers being sent after event closes.</li>
		<li>all - quotes are sent to the buyer system as soon as supplier submits the bid. It does not wait 
			for event closing.</li>
		</ul>
-->
<!ATTLIST QuoteRequestHeader
    requestID    %string;        #REQUIRED
    requestDate  %datetime.tz;   #REQUIRED
    type       (new | update | delete)  "new"
    openDate  %datetime.tz;      #REQUIRED
    closeDate %datetime.tz;      #REQUIRED
    previewDate %datetime.tz;    #IMPLIED
    templateName %string;        #IMPLIED
    currency  %isoCurrencyCode;  #REQUIRED
    xml:lang  %xmlLangCode;      #REQUIRED
    quoteReceivingPreference   (winningOnly | finalBidsFromAll | all)   #IMPLIED
>

<!--
    Defines the way suppliers are selected for responding to RFQ.

    The field is optional. Administrator can configure the default matching type for a given category 
	of commodity. Hence, If no value is provided here, the matching type will be picked up from 
	administrator's configuration. If the value is provided here, then administrator configuration 
	will be ignored. To know more talk to your administrator.

    OrganizationID is used to select explicit suppliers to be invited for bidding.
-->
<!ELEMENT SupplierSelector (SupplierInvitation*)>
<!--
    @attr matchingType Specifies how suppliers are invited for a quoteRequest. Possible values:
		<ul>
		<li>invitationOnly - Only invited suppliers. Suppliers that can join the event are specified in the 
			OrganizationID element.</li>
		<li>approvedVendorOnly - Suppliers from the approved supplier list. However, the sourcing application 
			may filter the suppliers that can bid based on the commodity and territory matching rules.</li>
		<li>public - Any public supplier. The supplier can also exist in the approved supplier list. However, 
			the sourcing application may filter the suppliers that can bid based on the commodity and 
			territory matching rules.</li>
		</ul>
-->
<!ATTLIST SupplierSelector
    matchingType (invitationOnly|approvedVendorOnly|public) #IMPLIED
>

<!--
	Represents explicit invitation for a supplier.

	Correspondent is used to supplier's contact information from ERP to network or sourcing system. 
	If the supplier does not already exists in the receiving system this information can be used 
	to create the supplier and contact the supplier.

	OrganizationID will have credential information that can uniquely identify the supplier in the ERP.
-->
<!ELEMENT SupplierInvitation (OrganizationID, Correspondent?, MasterAgreementIDInfo?, Extrinsic*)>
<!--
	@attr supplierStatus Status of supplier in the buyer's system. Possible values:
		<ul>
		<li>approved (default) - The supplier exists in the buyer's system and is approved by the buyer.</li>
		<li>contracted - The supplier is an approved supplier in the buyer's system and has an associated 
			master agreement of a contract. The buyer can specify the MasterAgreementIDInfo.</li>
		</ul>
-->
<!ATTLIST SupplierInvitation
    supplierStatus       (approved | contracted )  "approved"
>

<!--
    For more information about these elements/entities, see the 
    cXML Reference Guide and related documents.
-->

