<!--
    For cXML license agreement information, please see
    http://www.cxml.org/home/license.asp

    $Id: //ariba/cxml/release/schema/1.2.61.1+/Modules/Subscription.mod#1 $
-->

<!--
    Indicates that something changed in a buyer's content subscription.
    Since this is a Message, it can come at any time. No explicit Request
    needs to be sent first.
-->
<!ELEMENT SubscriptionChangeMessage (Subscription+)>
<!--
    @attr type The type of change message (enumeration).
-->
<!ATTLIST SubscriptionChangeMessage
    type  (new | update | delete)  #REQUIRED
>

<!--
    A content subscription.
-->
<!ELEMENT Subscription (InternalID, SubscriptionVersion?, Name, Changetime, SupplierID+, Format?,
                        Description?)>

<!--
	Contains the date and time when any aspect of the subscription last changed.
-->
<!ELEMENT Changetime (#PCDATA)> <!-- datetime.tz -->
<!--
	Contains the format of the catalog.
-->
<!ELEMENT Format (#PCDATA)> <!-- string -->
<!--
	@attr version The version of the catalog format.
-->
<!ATTLIST Format
    version  %string;  #REQUIRED
>

<!--
    Requests a complete list of catalog subscriptions for a buyer.
-->
<!ELEMENT SubscriptionListRequest EMPTY>

<!--
    The list of Subscriptions for the given buyer.
-->
<!ELEMENT SubscriptionListResponse (Subscription+)>

<!--
    Requests the contents of a catalog that the buyer is subscribed to.
-->
<!ELEMENT SubscriptionContentRequest (InternalID, SubscriptionVersion?, SupplierID+)>

<!--
    The data associated with a particular subscription.
-->
<!ELEMENT SubscriptionContentResponse (Subscription, SubscriptionContent+)>

<!--
    The actual content associated with a particular subscription.

    Use of the Contract element is deprecated.
-->
<!ELEMENT SubscriptionContent (CIFContent | Index | Contract)>
<!-- 
	@attr filename Filename for the subscription content.
-->
<!ATTLIST SubscriptionContent
    filename  %string;  #IMPLIED
>

<!--
    Contents of CIF file in base64 encoding.
-->
<!ELEMENT CIFContent (#PCDATA)> <!-- bin.base64 -->

<!--
    Indicates that something has changed in the supplier data for a supplier 
	the buyer has a relationship with. Since this is a message, no request 
	needs to be sent to receive this message.
-->
<!ELEMENT SupplierChangeMessage (Supplier+)>
<!--
    @attr type The type of change message.
-->
<!ATTLIST SupplierChangeMessage
    type  (new | update | delete)  #REQUIRED
>

<!--
    Requests for a complete list of suppliers the buyer currently has
    relationships with.
-->
<!ELEMENT SupplierListRequest EMPTY>

<!--
    The list of suppliers requested by SupplierListRequest.
-->
<!ELEMENT SupplierListResponse (Supplier+)>

<!--
    Requests for a data associated with a particular supplier identified by
    SupplierID.
-->
<!ELEMENT SupplierDataRequest (SupplierID+)>

<!--
    The data associated with the desired supplier.
-->
<!ELEMENT SupplierDataResponse (Supplier)>

<!--
	When a supplier edits a catalog, the network hub creates a new version of the catalog and assigns a 
	version number. This version number is used with the InternalID in all messages sent from the buyer to the 
	network hub. This is an optional attribute. When it is not defined, the network hub uses the last published 
	version of the catalog as the InternalID.
-->
<!ELEMENT SubscriptionVersion EMPTY>
<!--
	@attr versionNumber The requested version number of the catalog to fetch. If versionNumber is not provided, 
		the latest available version of the catalog is fetched.
-->
<!ATTLIST SubscriptionVersion
    versionNumber   %uint;  #REQUIRED
>

<!--
	Catalog subscription status from the buyer.
-->
<!ELEMENT SubscriptionStatus (Comments?)>
<!--
	@attr status The status of the catalog.
-->
<!ATTLIST SubscriptionStatus
      status    (received | validation_error | validated | approved | rejected | activated | deactivated | deleted | changed)  #REQUIRED>

<!--
	A request to update the subscription status of a Catalog. 

	InternalID: ID of the catalog.
	
	SubscriptionVersion: Contains the version number of the catalog.

	SubscriptionStatus: Contains the catalog subscription status from the buyer.
-->
<!ELEMENT SubscriptionStatusUpdateRequest (InternalID, SubscriptionVersion?, SubscriptionStatus)>
